'''version_warning.py

Module containing custom warning classes.

'''


class VersionWarning(UserWarning):
    '''VersionWarning

    A custom warning class for version warnings.
    '''


class MastapyImportWarning(ImportWarning):
    '''MastapyImportWarning

    A custom warning class for mastapy import warnings.
    '''
