'''_2393.py

CVTBeltConnectionCompoundSystemDeflection
'''


from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.system_deflections.compound import _2362
from mastapy._internal.python_net import python_net_import

_CVT_BELT_CONNECTION_COMPOUND_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Compound', 'CVTBeltConnectionCompoundSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('CVTBeltConnectionCompoundSystemDeflection',)


class CVTBeltConnectionCompoundSystemDeflection(_2362.BeltConnectionCompoundSystemDeflection):
    '''CVTBeltConnectionCompoundSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _CVT_BELT_CONNECTION_COMPOUND_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CVTBeltConnectionCompoundSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def belt_safety_factor_for_clamping_force(self) -> 'float':
        '''float: 'BeltSafetyFactorForClampingForce' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BeltSafetyFactorForClampingForce
