'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2355 import AbstractAssemblyCompoundSystemDeflection
    from ._2356 import AbstractShaftOrHousingCompoundSystemDeflection
    from ._2357 import AGMAGleasonConicalGearCompoundSystemDeflection
    from ._2358 import AGMAGleasonConicalGearMeshCompoundSystemDeflection
    from ._2359 import AGMAGleasonConicalGearSetCompoundSystemDeflection
    from ._2360 import AssemblyCompoundSystemDeflection
    from ._2361 import BearingCompoundSystemDeflection
    from ._2362 import BeltConnectionCompoundSystemDeflection
    from ._2363 import BeltDriveCompoundSystemDeflection
    from ._2364 import BevelDifferentialGearCompoundSystemDeflection
    from ._2365 import BevelDifferentialGearMeshCompoundSystemDeflection
    from ._2366 import BevelDifferentialGearSetCompoundSystemDeflection
    from ._2367 import BevelDifferentialPlanetGearCompoundSystemDeflection
    from ._2368 import BevelDifferentialSunGearCompoundSystemDeflection
    from ._2369 import BevelGearCompoundSystemDeflection
    from ._2370 import BevelGearMeshCompoundSystemDeflection
    from ._2371 import BevelGearSetCompoundSystemDeflection
    from ._2372 import BoltCompoundSystemDeflection
    from ._2373 import BoltedJointCompoundSystemDeflection
    from ._2374 import ClutchCompoundSystemDeflection
    from ._2375 import ClutchConnectionCompoundSystemDeflection
    from ._2376 import ClutchHalfCompoundSystemDeflection
    from ._2377 import CoaxialConnectionCompoundSystemDeflection
    from ._2378 import ComponentCompoundSystemDeflection
    from ._2379 import ConceptCouplingCompoundSystemDeflection
    from ._2380 import ConceptCouplingConnectionCompoundSystemDeflection
    from ._2381 import ConceptCouplingHalfCompoundSystemDeflection
    from ._2382 import ConceptGearCompoundSystemDeflection
    from ._2383 import ConceptGearMeshCompoundSystemDeflection
    from ._2384 import ConceptGearSetCompoundSystemDeflection
    from ._2385 import ConicalGearCompoundSystemDeflection
    from ._2386 import ConicalGearMeshCompoundSystemDeflection
    from ._2387 import ConicalGearSetCompoundSystemDeflection
    from ._2388 import ConnectionCompoundSystemDeflection
    from ._2389 import ConnectorCompoundSystemDeflection
    from ._2390 import CouplingCompoundSystemDeflection
    from ._2391 import CouplingConnectionCompoundSystemDeflection
    from ._2392 import CouplingHalfCompoundSystemDeflection
    from ._2393 import CVTBeltConnectionCompoundSystemDeflection
    from ._2394 import CVTCompoundSystemDeflection
    from ._2395 import CVTPulleyCompoundSystemDeflection
    from ._2396 import CylindricalGearCompoundSystemDeflection
    from ._2397 import CylindricalGearMeshCompoundSystemDeflection
    from ._2398 import CylindricalGearSetCompoundSystemDeflection
    from ._2399 import CylindricalPlanetGearCompoundSystemDeflection
    from ._2400 import DatumCompoundSystemDeflection
    from ._2401 import ExternalCADModelCompoundSystemDeflection
    from ._2402 import FaceGearCompoundSystemDeflection
    from ._2403 import FaceGearMeshCompoundSystemDeflection
    from ._2404 import FaceGearSetCompoundSystemDeflection
    from ._2405 import FlexiblePinAssemblyCompoundSystemDeflection
    from ._2406 import GearCompoundSystemDeflection
    from ._2407 import GearMeshCompoundSystemDeflection
    from ._2408 import GearSetCompoundSystemDeflection
    from ._2409 import GuideDxfModelCompoundSystemDeflection
    from ._2410 import HypoidGearCompoundSystemDeflection
    from ._2411 import HypoidGearMeshCompoundSystemDeflection
    from ._2412 import HypoidGearSetCompoundSystemDeflection
    from ._2413 import ImportedFEComponentCompoundSystemDeflection
    from ._2414 import InterMountableComponentConnectionCompoundSystemDeflection
    from ._2415 import KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection
    from ._2416 import KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection
    from ._2417 import KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection
    from ._2418 import KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection
    from ._2419 import KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection
    from ._2420 import KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection
    from ._2421 import KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection
    from ._2422 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection
    from ._2423 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection
    from ._2424 import MassDiscCompoundSystemDeflection
    from ._2425 import MeasurementComponentCompoundSystemDeflection
    from ._2426 import MountableComponentCompoundSystemDeflection
    from ._2427 import OilSealCompoundSystemDeflection
    from ._2428 import PartCompoundSystemDeflection
    from ._2429 import PartToPartShearCouplingCompoundSystemDeflection
    from ._2430 import PartToPartShearCouplingConnectionCompoundSystemDeflection
    from ._2431 import PartToPartShearCouplingHalfCompoundSystemDeflection
    from ._2432 import PlanetaryConnectionCompoundSystemDeflection
    from ._2433 import PlanetaryGearSetCompoundSystemDeflection
    from ._2434 import PlanetCarrierCompoundSystemDeflection
    from ._2435 import PointLoadCompoundSystemDeflection
    from ._2436 import PowerLoadCompoundSystemDeflection
    from ._2437 import PulleyCompoundSystemDeflection
    from ._2438 import RollingRingAssemblyCompoundSystemDeflection
    from ._2439 import RollingRingCompoundSystemDeflection
    from ._2440 import RollingRingConnectionCompoundSystemDeflection
    from ._2441 import RootAssemblyCompoundSystemDeflection
    from ._2442 import ShaftCompoundSystemDeflection
    from ._2443 import ShaftDutyCycleSystemDeflection
    from ._2444 import ShaftHubConnectionCompoundSystemDeflection
    from ._2445 import ShaftToMountableComponentConnectionCompoundSystemDeflection
    from ._2446 import SpecialisedAssemblyCompoundSystemDeflection
    from ._2447 import SpiralBevelGearCompoundSystemDeflection
    from ._2448 import SpiralBevelGearMeshCompoundSystemDeflection
    from ._2449 import SpiralBevelGearSetCompoundSystemDeflection
    from ._2450 import SpringDamperCompoundSystemDeflection
    from ._2451 import SpringDamperConnectionCompoundSystemDeflection
    from ._2452 import SpringDamperHalfCompoundSystemDeflection
    from ._2453 import StraightBevelDiffGearCompoundSystemDeflection
    from ._2454 import StraightBevelDiffGearMeshCompoundSystemDeflection
    from ._2455 import StraightBevelDiffGearSetCompoundSystemDeflection
    from ._2456 import StraightBevelGearCompoundSystemDeflection
    from ._2457 import StraightBevelGearMeshCompoundSystemDeflection
    from ._2458 import StraightBevelGearSetCompoundSystemDeflection
    from ._2459 import StraightBevelPlanetGearCompoundSystemDeflection
    from ._2460 import StraightBevelSunGearCompoundSystemDeflection
    from ._2461 import SynchroniserCompoundSystemDeflection
    from ._2462 import SynchroniserHalfCompoundSystemDeflection
    from ._2463 import SynchroniserPartCompoundSystemDeflection
    from ._2464 import SynchroniserSleeveCompoundSystemDeflection
    from ._2465 import TorqueConverterCompoundSystemDeflection
    from ._2466 import TorqueConverterConnectionCompoundSystemDeflection
    from ._2467 import TorqueConverterPumpCompoundSystemDeflection
    from ._2468 import TorqueConverterTurbineCompoundSystemDeflection
    from ._2469 import UnbalancedMassCompoundSystemDeflection
    from ._2470 import VirtualComponentCompoundSystemDeflection
    from ._2471 import WormGearCompoundSystemDeflection
    from ._2472 import WormGearMeshCompoundSystemDeflection
    from ._2473 import WormGearSetCompoundSystemDeflection
    from ._2474 import ZerolBevelGearCompoundSystemDeflection
    from ._2475 import ZerolBevelGearMeshCompoundSystemDeflection
    from ._2476 import ZerolBevelGearSetCompoundSystemDeflection
