'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._972 import CustomSplineHalfDesign
    from ._973 import CustomSplineJointDesign
    from ._974 import DetailedSplineJointSettings
    from ._975 import DIN5480SplineHalfDesign
    from ._976 import DIN5480SplineJointDesign
    from ._977 import DudleyEffectiveLengthApproximationOption
    from ._978 import FitTypes
    from ._979 import GBT3478SplineHalfDesign
    from ._980 import GBT3478SplineJointDesign
    from ._981 import HeatTreatmentTypes
    from ._982 import ISO4156SplineHalfDesign
    from ._983 import ISO4156SplineJointDesign
    from ._984 import JISB1603SplineJointDesign
    from ._985 import ManufacturingTypes
    from ._986 import Modules
    from ._987 import PressureAngleTypes
    from ._988 import RootTypes
    from ._989 import SAEFatigueLifeFactorTypes
    from ._990 import SAESplineHalfDesign
    from ._991 import SAESplineJointDesign
    from ._992 import SAETorqueCycles
    from ._993 import SplineDesignTypes
    from ._994 import FinishingMethods
    from ._995 import SplineFitClassType
    from ._996 import SplineFixtureTypes
    from ._997 import SplineHalfDesign
    from ._998 import SplineJointDesign
    from ._999 import SplineMaterial
    from ._1000 import SplineRatingTypes
    from ._1001 import SplineToleranceClassTypes
    from ._1002 import StandardSplineHalfDesign
    from ._1003 import StandardSplineJointDesign
