'''_5666.py

AbstractShaftOrHousingCompoundGearWhineAnalysis
'''


from mastapy.system_model.analyses_and_results.gear_whine_analyses.compound import _5688
from mastapy._internal.python_net import python_net_import

_ABSTRACT_SHAFT_OR_HOUSING_COMPOUND_GEAR_WHINE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses.Compound', 'AbstractShaftOrHousingCompoundGearWhineAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('AbstractShaftOrHousingCompoundGearWhineAnalysis',)


class AbstractShaftOrHousingCompoundGearWhineAnalysis(_5688.ComponentCompoundGearWhineAnalysis):
    '''AbstractShaftOrHousingCompoundGearWhineAnalysis

    This is a mastapy class.
    '''

    TYPE = _ABSTRACT_SHAFT_OR_HOUSING_COMPOUND_GEAR_WHINE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'AbstractShaftOrHousingCompoundGearWhineAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
