'''_5743.py

PlanetaryGearSetCompoundGearWhineAnalysis
'''


from mastapy.system_model.analyses_and_results.gear_whine_analyses.compound import _5708
from mastapy._internal.python_net import python_net_import

_PLANETARY_GEAR_SET_COMPOUND_GEAR_WHINE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses.Compound', 'PlanetaryGearSetCompoundGearWhineAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('PlanetaryGearSetCompoundGearWhineAnalysis',)


class PlanetaryGearSetCompoundGearWhineAnalysis(_5708.CylindricalGearSetCompoundGearWhineAnalysis):
    '''PlanetaryGearSetCompoundGearWhineAnalysis

    This is a mastapy class.
    '''

    TYPE = _PLANETARY_GEAR_SET_COMPOUND_GEAR_WHINE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PlanetaryGearSetCompoundGearWhineAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
