'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1006 import AGMA6123SplineHalfRating
    from ._1007 import AGMA6123SplineJointRating
    from ._1008 import DIN5466SplineHalfRating
    from ._1009 import DIN5466SplineRating
    from ._1010 import GBT17855SplineHalfRating
    from ._1011 import GBT17855SplineJointRating
    from ._1012 import SAESplineHalfRating
    from ._1013 import SAESplineJointRating
    from ._1014 import SplineHalfRating
    from ._1015 import SplineJointRating
