'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3600 import AbstractAssemblyCompoundParametricStudyTool
    from ._3601 import AbstractShaftOrHousingCompoundParametricStudyTool
    from ._3602 import AGMAGleasonConicalGearCompoundParametricStudyTool
    from ._3603 import AGMAGleasonConicalGearMeshCompoundParametricStudyTool
    from ._3604 import AGMAGleasonConicalGearSetCompoundParametricStudyTool
    from ._3605 import AssemblyCompoundParametricStudyTool
    from ._3606 import BearingCompoundParametricStudyTool
    from ._3607 import BeltConnectionCompoundParametricStudyTool
    from ._3608 import BeltDriveCompoundParametricStudyTool
    from ._3609 import BevelDifferentialGearCompoundParametricStudyTool
    from ._3610 import BevelDifferentialGearMeshCompoundParametricStudyTool
    from ._3611 import BevelDifferentialGearSetCompoundParametricStudyTool
    from ._3612 import BevelDifferentialPlanetGearCompoundParametricStudyTool
    from ._3613 import BevelDifferentialSunGearCompoundParametricStudyTool
    from ._3614 import BevelGearCompoundParametricStudyTool
    from ._3615 import BevelGearMeshCompoundParametricStudyTool
    from ._3616 import BevelGearSetCompoundParametricStudyTool
    from ._3617 import BoltCompoundParametricStudyTool
    from ._3618 import BoltedJointCompoundParametricStudyTool
    from ._3619 import ClutchCompoundParametricStudyTool
    from ._3620 import ClutchConnectionCompoundParametricStudyTool
    from ._3621 import ClutchHalfCompoundParametricStudyTool
    from ._3622 import CoaxialConnectionCompoundParametricStudyTool
    from ._3623 import ComponentCompoundParametricStudyTool
    from ._3624 import ConceptCouplingCompoundParametricStudyTool
    from ._3625 import ConceptCouplingConnectionCompoundParametricStudyTool
    from ._3626 import ConceptCouplingHalfCompoundParametricStudyTool
    from ._3627 import ConceptGearCompoundParametricStudyTool
    from ._3628 import ConceptGearMeshCompoundParametricStudyTool
    from ._3629 import ConceptGearSetCompoundParametricStudyTool
    from ._3630 import ConicalGearCompoundParametricStudyTool
    from ._3631 import ConicalGearMeshCompoundParametricStudyTool
    from ._3632 import ConicalGearSetCompoundParametricStudyTool
    from ._3633 import ConnectionCompoundParametricStudyTool
    from ._3634 import ConnectorCompoundParametricStudyTool
    from ._3635 import CouplingCompoundParametricStudyTool
    from ._3636 import CouplingConnectionCompoundParametricStudyTool
    from ._3637 import CouplingHalfCompoundParametricStudyTool
    from ._3638 import CVTBeltConnectionCompoundParametricStudyTool
    from ._3639 import CVTCompoundParametricStudyTool
    from ._3640 import CVTPulleyCompoundParametricStudyTool
    from ._3641 import CylindricalGearCompoundParametricStudyTool
    from ._3642 import CylindricalGearMeshCompoundParametricStudyTool
    from ._3643 import CylindricalGearSetCompoundParametricStudyTool
    from ._3644 import CylindricalPlanetGearCompoundParametricStudyTool
    from ._3645 import DatumCompoundParametricStudyTool
    from ._3646 import ExternalCADModelCompoundParametricStudyTool
    from ._3647 import FaceGearCompoundParametricStudyTool
    from ._3648 import FaceGearMeshCompoundParametricStudyTool
    from ._3649 import FaceGearSetCompoundParametricStudyTool
    from ._3650 import FlexiblePinAssemblyCompoundParametricStudyTool
    from ._3651 import GearCompoundParametricStudyTool
    from ._3652 import GearMeshCompoundParametricStudyTool
    from ._3653 import GearSetCompoundParametricStudyTool
    from ._3654 import GuideDxfModelCompoundParametricStudyTool
    from ._3655 import HypoidGearCompoundParametricStudyTool
    from ._3656 import HypoidGearMeshCompoundParametricStudyTool
    from ._3657 import HypoidGearSetCompoundParametricStudyTool
    from ._3658 import ImportedFEComponentCompoundParametricStudyTool
    from ._3659 import InterMountableComponentConnectionCompoundParametricStudyTool
    from ._3660 import KlingelnbergCycloPalloidConicalGearCompoundParametricStudyTool
    from ._3661 import KlingelnbergCycloPalloidConicalGearMeshCompoundParametricStudyTool
    from ._3662 import KlingelnbergCycloPalloidConicalGearSetCompoundParametricStudyTool
    from ._3663 import KlingelnbergCycloPalloidHypoidGearCompoundParametricStudyTool
    from ._3664 import KlingelnbergCycloPalloidHypoidGearMeshCompoundParametricStudyTool
    from ._3665 import KlingelnbergCycloPalloidHypoidGearSetCompoundParametricStudyTool
    from ._3666 import KlingelnbergCycloPalloidSpiralBevelGearCompoundParametricStudyTool
    from ._3667 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundParametricStudyTool
    from ._3668 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundParametricStudyTool
    from ._3669 import MassDiscCompoundParametricStudyTool
    from ._3670 import MeasurementComponentCompoundParametricStudyTool
    from ._3671 import MountableComponentCompoundParametricStudyTool
    from ._3672 import OilSealCompoundParametricStudyTool
    from ._3673 import PartCompoundParametricStudyTool
    from ._3674 import PartToPartShearCouplingCompoundParametricStudyTool
    from ._3675 import PartToPartShearCouplingConnectionCompoundParametricStudyTool
    from ._3676 import PartToPartShearCouplingHalfCompoundParametricStudyTool
    from ._3677 import PlanetaryConnectionCompoundParametricStudyTool
    from ._3678 import PlanetaryGearSetCompoundParametricStudyTool
    from ._3679 import PlanetCarrierCompoundParametricStudyTool
    from ._3680 import PointLoadCompoundParametricStudyTool
    from ._3681 import PowerLoadCompoundParametricStudyTool
    from ._3682 import PulleyCompoundParametricStudyTool
    from ._3683 import RollingRingAssemblyCompoundParametricStudyTool
    from ._3684 import RollingRingCompoundParametricStudyTool
    from ._3685 import RollingRingConnectionCompoundParametricStudyTool
    from ._3686 import RootAssemblyCompoundParametricStudyTool
    from ._3687 import ShaftCompoundParametricStudyTool
    from ._3688 import ShaftHubConnectionCompoundParametricStudyTool
    from ._3689 import ShaftToMountableComponentConnectionCompoundParametricStudyTool
    from ._3690 import SpecialisedAssemblyCompoundParametricStudyTool
    from ._3691 import SpiralBevelGearCompoundParametricStudyTool
    from ._3692 import SpiralBevelGearMeshCompoundParametricStudyTool
    from ._3693 import SpiralBevelGearSetCompoundParametricStudyTool
    from ._3694 import SpringDamperCompoundParametricStudyTool
    from ._3695 import SpringDamperConnectionCompoundParametricStudyTool
    from ._3696 import SpringDamperHalfCompoundParametricStudyTool
    from ._3697 import StraightBevelDiffGearCompoundParametricStudyTool
    from ._3698 import StraightBevelDiffGearMeshCompoundParametricStudyTool
    from ._3699 import StraightBevelDiffGearSetCompoundParametricStudyTool
    from ._3700 import StraightBevelGearCompoundParametricStudyTool
    from ._3701 import StraightBevelGearMeshCompoundParametricStudyTool
    from ._3702 import StraightBevelGearSetCompoundParametricStudyTool
    from ._3703 import StraightBevelPlanetGearCompoundParametricStudyTool
    from ._3704 import StraightBevelSunGearCompoundParametricStudyTool
    from ._3705 import SynchroniserCompoundParametricStudyTool
    from ._3706 import SynchroniserHalfCompoundParametricStudyTool
    from ._3707 import SynchroniserPartCompoundParametricStudyTool
    from ._3708 import SynchroniserSleeveCompoundParametricStudyTool
    from ._3709 import TorqueConverterCompoundParametricStudyTool
    from ._3710 import TorqueConverterConnectionCompoundParametricStudyTool
    from ._3711 import TorqueConverterPumpCompoundParametricStudyTool
    from ._3712 import TorqueConverterTurbineCompoundParametricStudyTool
    from ._3713 import UnbalancedMassCompoundParametricStudyTool
    from ._3714 import VirtualComponentCompoundParametricStudyTool
    from ._3715 import WormGearCompoundParametricStudyTool
    from ._3716 import WormGearMeshCompoundParametricStudyTool
    from ._3717 import WormGearSetCompoundParametricStudyTool
    from ._3718 import ZerolBevelGearCompoundParametricStudyTool
    from ._3719 import ZerolBevelGearMeshCompoundParametricStudyTool
    from ._3720 import ZerolBevelGearSetCompoundParametricStudyTool
